img.preview_image_small {
    width: 150px;
    box-shadow: 0px 0px 5px 0px black;
    margin: 5px;
}
div.preview_image {
    display: none;
    z-index: 999;
    position: fixed;
    top: 0px;
    left: 0px;
    right: 0px;
    bottom: 0px;
    text-align: center;
}
div.preview_image img {
    margin: 15px;
    box-shadow: 0px 0px 15px 0px black;
}
