.result_list__ident_span {
    display: block;
    float: left;
    height: 10px;
    width: 25px;
}
.drag_handle_container {
    display: inline-block;
    position: absolute;
}
.drag_handle {
    width: 16px;
    height: 16px;
    background-image: url('../img/icon-drag.png');
    cursor: move;
    position: relative;
    left: 15px;
    top: -1px;
    opacity: 0.5;
}
.drag_handle:hover {
    opacity: 1.0;
}

#position_place {
    position: absolute;
}
#position_place div {
    height: 6px;
    width: 500px;
    background-color: #6CA8F5;
    position: absolute;
    top: 2px;
    z-index: 99;
}

#loader {
    display: none;
    position: absolute;
    top: 0px;
    left: 0px;
    right: 0px;
    bottom: 0px;
    background-color: black;
    opacity: 0.1;
}
