{% extends 'base.html' %}
{% load sitemenu %}

{% block page_title %}{% if menu.get_page_title %}{{ menu.get_page_title }} | {% endif %}{{ block.super }}{% endblock page_title %}

{% block content %}
    <h1>{{ menu.title }}</h1>
    {{ menu.content }}
{% endblock content %}
